<?php

namespace TOT\Integrations\WooCommerce;

use TOT\Settings\Page;

class Settings
{
    private $text_domain;

    function __construct()
    {
        global $tot_plugin_text_domain;
        $this->text_domain = $tot_plugin_text_domain;
        add_action('woocommerce_init', array($this, 'register_wordpress_hooks_after_load'));
    }

    public function register_wordpress_hooks_after_load()
    {
        if (!class_exists('WooCommerce')) {
            return;
        }

        add_action('admin_menu', array($this, 'create_page'));
        add_action('admin_notices', array($this, 'admin_notice'));
        add_action('admin_init', array($this, 'admin_init'));
    }

    public function admin_init()
    {
        if (isset($_GET['page']) && (sanitize_text_field($_GET['page']) != 'tot_settings_woocommerce')) {
            return;
        }

        if (!$this->is_beta_enabled()) {
            tot_refresh_keys();
        }
    }

    public function is_beta_enabled()
    {
            return true;
    }

    public function admin_notice()
    {

        if (!isset($_GET['page']) || (sanitize_text_field($_GET['page']) != 'tot_settings_woocommerce')) {
            return;
        }

        if ($this->is_beta_enabled()) {
            return;
        }
    }

    public function create_page()
    {

        if (!$this->is_beta_enabled()) {
            new Page('WooCommerce', array());
            return;
        }

        $payment_options = array();
        $gateways = WC()->payment_gateways->payment_gateways();
        if (!is_wp_error($gateways)) {
            forEach ($gateways as $method) {
                if(isset( $method->enabled ) && 'yes' === $method->enabled  ) {
                    array_push($payment_options, array(
                        'label' => $method->title,
                        'value' => $method->id
                    ));
                }
            }
            // List disabled AFTER enabled.
            forEach ($gateways as $method) {
                if(!isset( $method->enabled ) || 'yes' !== $method->enabled  ) {
                    array_push($payment_options, array(
                        'label' => $method->title . ' (disabled)',
                        'value' => $method->id
                    ));
                }
            }
        }

        $shipping_options = array();
        $shipping_methods = WC()->shipping->get_shipping_methods();
        // tot_log_as_html_pre("Shipping_Methods", $shipping_methods);
        if (!is_wp_error($shipping_methods)) {
            forEach ($shipping_methods as $method) {
                if(isset( $method->enabled ) && 'yes' === $method->enabled  ) {
                    array_push($shipping_options, array(
                        'label' => $method->method_title,
                        'value' => $method->id
                    ));
                }
            }
            // List disabled AFTER enabled.
            forEach ($shipping_methods as $method) {
                if(!isset( $method->enabled ) || 'yes' !== $method->enabled  ) {
                    array_push($shipping_options, array(
                        'label' => $method->method_title . ' (disabled)',
                        'value' => $method->id
                    ));
                }
            }
        }

        $category_options = array();
        $category_results = get_terms('product_cat', array(
            'orderby' => 'name',
            'order' => 'asc',
            'hide_empty' => false,
        ));
        if (!is_wp_error($category_results)) {
            forEach ($category_results as $category) {
                array_push($category_options, array(
                    'label' => $category->name,
                    'value' => $category->term_id
                ));
            }
        }

        $tag_options = array();
        $tag_results = get_terms('product_tag', array(
            'orderby' => 'name',
            'order' => 'asc',
            'hide_empty' => false,
        ));
        if (!is_wp_error($tag_results)) {
            forEach ($tag_results as $tag) {
                array_push($tag_options, array(
                    'label' => $tag->name,
                    'value' => $tag->term_id
                ));
            }
        }

        $try_order_verification_url = get_site_url() . '?checkout_require=1';
        $try_order_verifications_anchor = '<a href="' . $try_order_verification_url . '">' . $try_order_verification_url . '</a>';

        new Page('WooCommerce', array(
            __('Order Verification', $this->text_domain) => array(
                'description' => '',
                'fields' => array(
                    array(
                        'id' => 'checkout_require',
                        'type' => 'checkbox',
                        'label' => __('Enable checkout verification', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __("Enabling this turns on Token of Trust verification on woo commerce checkouts. If left unchecked Token of Trust will not be enabled during the Woo Commerce checkout process and none of the settings below will take effect. ", $this->text_domain)
                                . '<br><br>' . __('Advanced: To test without enabling for your entire site, copy this link, paste into a new incognito window and go through the checkout process. Your incognito session will behave as if checkout verification is active for about 30 minutes: : ', $this->text_domain) . $try_order_verifications_anchor
                            )
                        )
                    ),
                    array(
                        'id' => 'woo_enable_verification_before_payment',
                        'type' => 'checkbox',
                        'label' => __('Enable "Verification Before Payment"', $this->text_domain),
                        'options' => array(
                            'prepend' => array(
                            ),
                            'append' => array(
                                __('When checked Token of Trust will attempt to attach to the the checkout process before payment. If checkout verification is enabled and this option is not selected Token of Trust will ask for verification on the Thank You / Receipt page - after payment has been collected.', $this->text_domain)
                                . '<br><br>' . __('Advanced: If this is enabled but Token of Trust does not launch on checkout (possible for custom themes) - take a look at the "Verification Before Payment (jquery) Selector" in the Advanced section below.', $this->text_domain)
                            ),
                            'default_value' => true
                        )
                    ),
                ),
            ),
            __('Orders Considered for Verification', $this->text_domain) => array(
                'description' => __('Orders matching ANY of these conditions are considered for verification.', $this->text_domain),
                'fields' => array(
                    array(
                        'id' => 'checkout_require_total_amount',
                        'type' => 'currency',
                        'label' => __('Minimum order amount', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __('Example: 4.00', $this->text_domain),
                                __("Require verification for orders that are more than this amount. '0' to trigger verification on all orders. Empty means no orders will trigger verification.", $this->text_domain)
                            )
                        )
                    ),
                    array(
                        'id' => 'checkout_require_categories',
                        'type' => 'multiselect',
                        'label' => __('Categories', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __('Always require verification for orders containing a product with any of these categories.', $this->text_domain)
                            ),
                            'options' => $category_options
                        )
                    ),
                    array(
                        'id' => 'checkout_require_tags',
                        'type' => 'multiselect',
                        'label' => __('Tags', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __('Always require verification for orders containing a product with any of these tags.', $this->text_domain)
                            ),
                            'options' => $tag_options
                        )
                    )
                )
            ),
            __('Order Verification Requirements', $this->text_domain) => array(
                'description' => __('Leave these fields alone to verify all "Orders Considered for Verification" above. Add criteria below to limit considered orders to only those meeting these requirements.', $this->text_domain),
                'fields' => array(
                    array(
                        'id' => 'checkout_require_payment_methods',
                        'type' => 'multiselect',
                        'label' => __('Payment Methods Requiring Verification', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __('Require verification for orders using these payment methods. Leave empty to accept all current and future payment methods.', $this->text_domain)
                            ),
                            'options' => $payment_options
                        )
                    ),
                    array(
                        'id' => 'checkout_require_shipping_methods',
                        'type' => 'multiselect',
                        'label' => __('Shipping Methods Requiring Verification', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __('Require verification for orders using these shipping methods. Leave empty to accept all current and future shipping methods.', $this->text_domain)
                            ),
                            'options' => $shipping_options
                        )
                    ),
                )
            ),
            __('Verification results', $this->text_domain) => array(
                'description' => '',
                'fields' => array(
                    array(
                        'id' => 'min_age',
                        'type' => 'number',
                        'label' => __('Minimum age', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __('When configured for "Age Verification" (check your API key settings or contact support@tokenoftrust.com for assistance) - Accepts orders when the verified age is greater than this.', $this->text_domain)
                            )
                        )
                    ),
                ),
            ),
            __('Advanced', $this->text_domain) => array(
                'description' => 'Only modify these options if you\'ve been directed to do so by Token of Trust support.',
                'fields' => array(
                    array(
                        'id' => 'woo_verification_before_payment_selector',
                        'type' => 'text',
                        'label' => __('Verification Before Payment (jquery) Selector', $this->text_domain),
                        'options' => array(
                            'prepend' => array(
                            ),
                            'append' => array(
                                __('The (jquery style) selector to use to find the elements to bind verification to. The default selector is "#place_order". Developers and integrators can test their value from the console via `$(selectorValue)`.', $this->text_domain)
                            ),
                            'default_value' => '#place_order'
                        )
                    ),
                    array(
                        'id' => 'woo_disable_status_on_orders_page',
                        'type' => 'checkbox',
                        'label' => __('Disable "Verification Status"', $this->text_domain),
                        'options' => array(
                            'prepend' => array(
                            ),
                            'append' => array(
                                __('When checked removes the "Verification Status" column from the Woo Commerce Orders page.', $this->text_domain)
                            )
                        )

                    ),
                    array(
                        'id' => 'woo_enable_tot_states',
                        'type' => 'checkbox',
                        'label' => __('Enable "Awaiting Verification" and "Ready for Review".', $this->text_domain),
                        'options' => array(
                            'prepend' => array(
                            ),
                            'append' => array(
                                __('Allows TOT to move orders into custom Woo Commerce Statuses "Awaiting Verification" and "Ready for Review". Warning this feature can result in unintended behaviors related to your payment gateway as well as incompatibilities with other features and plugins that depend upon Woo Commerce Status.', $this->text_domain)
                            )
                        )
                    ),
                    array(
                        'id' => 'dont_force_accept_on_app_approve',
                        'type' => 'checkbox',
                        'label' => __('(Advanced) Admin Review no override.', $this->text_domain),
                        'options' => array(
                            'prepend' => array(),
                            'append' => array(
                                __('When checked Admin Review of IDs means that documents (e.g. govt ID) are approved but other rules (e.g. age) are still verified independently to determine if the order can automatically move out of "Awaiting Verification".', $this->text_domain)
                            )
                        )
                    ),

                ),
            ),
        ));
    }

}
