<?php
/**
 *
 * Settings
 *
 */

namespace TOT;

/**
 * WARNING : use of tot_log_as_html_comment doesn't work well here and can cause HTML corruption!!
 */

class Settings {

	public static $key = 'tot_options';
    public static $prefix = 'tot_field_';

	private function __construct() {}

	public static function get_setting($key) {
        $cookie = self::get_param_or_cookie($key);
        if (isset($cookie)) {
            // tot_log_as_html_comment("Found Param or Cookie '$key'", $cookie);
            return $cookie;
        }

        $do_get_setting = self::do_get_setting($key);
        // tot_log_as_html_comment("Found Option '$key'", $do_get_setting);
        return $do_get_setting;
    }

    /**
     * Strips 'tot_field_' off if present and looks for a query param and cookie of remaining name.
     *
     * @param $key
     * @return object
     */
    public static function get_param_or_cookie($key) {
        $key = self::stripTotFieldKey($key);
//        tot_log_as_html_comment('TOT - searching via get_query_var for ', $key);
        $query_var = get_query_var($key, NULL);
        if (isset($query_var)) {
//             tot_log_as_html_comment('TOT override - found via get_query_var', array(
//                $key => $query_var
//            ));
            return $query_var;
        }
        $cookieValue = ($key && isset($_COOKIE[$key])) ? $_COOKIE[$key] : NULL;
        // tot_log_as_html_comment('TOT - searching via get_query_var for ', $key);
        if (isset($cookieValue)) {
//             tot_log_as_html_comment('TOT override - found cookie value', array(
//                $key => $cookieValue
//            ));
            return $cookieValue;
        }
        return NULL;
    }



    public static function set_setting($key, $value) {
        $key = Settings::expandTotFieldKey($key);
        $options = get_option(self::$key);

		if(!isset($options) || !is_array($options)) {
			$options = array();
		}

		$options[$key] = $value;
		update_option('tot_options', $options);
//         tot_log_as_html_comment('TOT - set_setting', array(
//            $key => $value
//        ));
    }

    /**
     * @param $key
     * @return false|mixed|string
     */
    public static function stripTotFieldKey($key) {
        $prefixPos = strpos($key, self::$prefix);
        if ($prefixPos === 0) {
            // Strip prefix so cookie names are consistent with variable names.
            $key = substr($key, strlen(self::$prefix));
        }
        return $key;
    }

    /**
     * @param $key
     * @return false|mixed|string
     */
    public static function expandTotFieldKey($key) {
        $prefixPos = strpos($key, self::$prefix);
        if ($prefixPos !== 0) {
            $key = self::$prefix . $key;
        }
        return $key;
    }

    /**
     * @param $key
     * @return mixed
     */
    public static function do_get_setting($key)
    {
        $key = Settings::expandTotFieldKey($key);

        // Add prefix if it's not present (to maintain back compatibility).
        $options = get_option(self::$key);
        if (isset($key) && $options && isset($options) && array_key_exists($key, $options)) {
            return $options[$key];
        }
    }
}